"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const bull_1 = __importDefault(require("bull"));
const utils_1 = require("./utils");
const fs_1 = __importDefault(require("fs"));
let queue;
async function getQueue() {
    if (!queue) {
        return utils_1.throwYellow("Need connect before");
    }
    return await queue.isReady();
}
exports.getQueue = getQueue;
async function setQueue(name, url, options) {
    queue && (await queue.close());
    queue = bull_1.default(name, url, options);
    await queue.isReady();
}
exports.setQueue = setQueue;
async function connectToQueue({ queue: name, options }, vorpal) {
    var _a;
    const prefix = options.prefix || "bull";
    const host = options.host || "localhost";
    const port = options.port || 6379;
    const db = (_a = options.db) !== null && _a !== void 0 ? _a : 0;
    const password = options.password || void 0;
    const tls = options.cert
        ? {
            ca: fs_1.default.readFileSync(options.cert),
            rejectUnauthorized: false
        }
        : void 0;
    await setQueue(name, "", {
        prefix,
        redis: {
            host,
            port,
            db,
            password,
            tls
        }
    });
    vorpal.localStorage.setItem(utils_1.LAST_SAVED_CONNECTION_NAME, JSON.stringify({
        queue: name,
        options
    }));
    utils_1.logGreen(`Connected to ${host}:${port}, prefix: ${prefix}, queue: ${name}`);
    vorpal.delimiter(`BULL-REPL | ${prefix}.${name}> `).show();
}
exports.connectToQueue = connectToQueue;
